@@ -1,12 +1,11 @@
-import requests
-from urllib.parse import urljoin
+import httpx
 from .typings import IndexPayload, SearchPayload, TunePayload
 
 
 BASE_API = "https://api.getmetal.io"
 
 
-class Metal(requests.Session):
+class Metal(httpx.Client):
     api_key: str
     client_id: str
     app_id: str
@@ -24,7 +23,7 @@ class Metal(requests.Session):
         self.base_url = base_url
 
     def request(self, method, url, *args, **kwargs):
-        return super().request(method, urljoin(self.base_url, url), *args, **kwargs)
+        return super().request(method, url, *args, **kwargs)
 
     def __getData(self, app, payload: dict = {}):
         data = {"app": app}
@@ -65,16 +64,16 @@ class Metal(requests.Session):
         return res.json()
 
     def search(
-        self, payload: SearchPayload = {}, app_id=None, ids_only=False
+        self, payload: SearchPayload = {}, app_id=None, ids_only=False, limit=1
     ):
         app = app_id or self.app_id
         self.__validateIndexAndSearch(app, payload)
         data = self.__getData(app, payload)
 
-        url = "/v1/search"
+        url = "/v1/search?limit=" + str(limit)
 
         if ids_only:
-            url = url + "?idsOnly=true"
+            url = url + "&idsOnly=true"
 
         res = self.request("post", url, json=data)
         res.raise_for_status()
@@ -99,3 +98,23 @@ class Metal(requests.Session):
         res = self.request("post", url, json=data)
         res.raise_for_status()
         return res.json()
+
+    def get_one(self, id: str, app_id=None):
+        if id is None:
+            raise TypeError("id required")
+
+        url = "/v1/documents/" + id
+
+        res = self.request("get", url)
+        res.raise_for_status()
+        return res.json()
+
+    def delete_one(self, id: str, app_id=None):
+        if id is None:
+            raise TypeError("id required")
+
+        url = "/v1/documents/" + id
+
+        res = self.request("delete", url)
+        res.raise_for_status()
+        return res.json()
