@@ -83,7 +83,7 @@ class TestMetal(TestCase):
         )
         self.assertEqual(
             metal.request.call_args[0][1],
-            "/v1/search?idsOnly=true",
+            "/v1/search?limit=1&idsOnly=true",
         )
         self.assertEqual(metal.request.call_args[1]["json"]["app"], my_app)
         self.assertEqual(metal.request.call_args[1]["json"]["text"], payload["text"])
@@ -116,3 +116,27 @@ class TestMetal(TestCase):
         self.assertEqual(metal.request.call_args[1]["json"]["idA"], payload["idA"])
         self.assertEqual(metal.request.call_args[1]["json"]["idB"], payload["idB"])
         self.assertEqual(metal.request.call_args[1]["json"]["label"], payload["label"])
+
+    def test_metal_get_one_with_payload(self):
+        app_id = "app-id"
+        id = "ozzy"
+        metal = Metal(API_KEY, CLIENT_ID, app_id)
+        return_value = mock.MagicMock(json=lambda: {"ozzy": "black sabbath"})
+        metal.request = mock.MagicMock(return_value=return_value)
+
+        metal.get_one(id)
+        self.assertEqual(metal.request.call_count, 1)
+        self.assertEqual(metal.request.call_args[0][0], "get")
+        self.assertEqual(metal.request.call_args[0][1], "/v1/documents/ozzy")
+
+    def test_metal_delete_one_with_payload(self):
+        app_id = "app-id"
+        id = "ozzy"
+        metal = Metal(API_KEY, CLIENT_ID, app_id)
+        return_value = mock.MagicMock(json=lambda: {"ozzy": "black sabbath"})
+        metal.request = mock.MagicMock(return_value=return_value)
+
+        metal.delete_one(id)
+        self.assertEqual(metal.request.call_count, 1)
+        self.assertEqual(metal.request.call_args[0][0], "delete")
+        self.assertEqual(metal.request.call_args[0][1], "/v1/documents/ozzy")
